==> ra-sdk-1.0.4.1-20200603.064959-2-sources.jar: com/xdja/ra/bean/IssueApplyInfo.java <==
package com.xdja.ra.bean;

/**
 * @author: ggp
 * @Date: 2019/10/22 20:12
 * @Description:
 */
public class IssueApplyInfo {
    /**
     *必须	申请原因
     */
    private String applyReason;
    /**
     *必须	申请状态 1:待审核 2:审核未通过 3:待签发 4:签发未通过 5:已签发 6:撤销失败 7:已撤销
     */
    private Integer applyStatus;
    /**
     *必须	申请证书DN
     */
    private String certDn;
    /**
     *必须	证书有效期
     */
    private Integer certValidity;
    /**
     *必须	申请创建时间
     */
    private String gmtCreate;
    /**
     *必须	密钥算法
     */
    private String keyAlg;
    /**
     *必须	用户证件编号
     */
    private String licenseNumber;
    /**
     *必须	不同类型用户相对应的用户身份类型 userType为1时 identType 1:身份证 2:军官证  3:护照 4:其它 userType为2时 identType 1:工商登记证 2:组织机构代码 3:税务登记证 4:其他 userType为3时 identType 1:服务器 2:手机 3:网站 4:其他
     */
    private Integer licenseType;
    /**
     *必须	密钥长度
     */
    private Integer privateKeyLength;
    /**
     *必须	证书签名算法
     */
    private String signAlg;
    /**
     *必须	模板名称
     */
    private String tempName;
    /**
     *必须	模板编号
     */
    private String tempNo;
    /**
     *必须	模板扩展参数
     */
    private String tempParas;
    /**
     *必须	申请用户的用户名
     */
    private String userName;
    /**
     *必须	申请用户的用户状态 0-正常 1-停用
     */
    private Integer userStatus;
    /**
     *必须	申请用户的用户类型 1-个人用户 2-机构用户 3-设备用户
     */
    private Integer userType;

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public Integer getCertValidity() {
        return certValidity;
    }

    public void setCertValidity(Integer certValidity) {
        this.certValidity = certValidity;
    }

    public String getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(String gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getKeyAlg() {
        return keyAlg;
    }

    public void setKeyAlg(String keyAlg) {
        this.keyAlg = keyAlg;
    }

    public String getLicenseNumber() {
        return licenseNumber;
    }

    public void setLicenseNumber(String licenseNumber) {
        this.licenseNumber = licenseNumber;
    }

    public Integer getLicenseType() {
        return licenseType;
    }

    public void setLicenseType(Integer licenseType) {
        this.licenseType = licenseType;
    }

    public Integer getPrivateKeyLength() {
        return privateKeyLength;
    }

    public void setPrivateKeyLength(Integer privateKeyLength) {
        this.privateKeyLength = privateKeyLength;
    }

    public String getSignAlg() {
        return signAlg;
    }

    public void setSignAlg(String signAlg) {
        this.signAlg = signAlg;
    }

    public String getTempName() {
        return tempName;
    }

    public void setTempName(String tempName) {
        this.tempName = tempName;
    }

    public String getTempNo() {
        return tempNo;
    }

    public void setTempNo(String tempNo) {
        this.tempNo = tempNo;
    }

    public String getTempParas() {
        return tempParas;
    }

    public void setTempParas(String tempParas) {
        this.tempParas = tempParas;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public Integer getUserStatus() {
        return userStatus;
    }

    public void setUserStatus(Integer userStatus) {
        this.userStatus = userStatus;
    }

    public Integer getUserType() {
        return userType;
    }

    public void setUserType(Integer userType) {
        this.userType = userType;
    }

    @Override
    public String toString() {
        return "IssueApplyInfo{" +
                "applyReason='" + applyReason + '\'' +
                ", applyStatus=" + applyStatus +
                ", certDn='" + certDn + '\'' +
                ", certValidity=" + certValidity +
                ", gmtCreate='" + gmtCreate + '\'' +
                ", keyAlg='" + keyAlg + '\'' +
                ", licenseNumber='" + licenseNumber + '\'' +
                ", licenseType=" + licenseType +
                ", privateKeyLength=" + privateKeyLength +
                ", signAlg='" + signAlg + '\'' +
                ", tempName='" + tempName + '\'' +
                ", tempNo='" + tempNo + '\'' +
                ", tempParas='" + tempParas + '\'' +
                ", userName='" + userName + '\'' +
                ", userStatus=" + userStatus +
                ", userType=" + userType +
                '}';
    }
}

==> ra-sdk-1.0.8-20211108.061226-6-sources.jar: com/xdja/ra/bean/IssueApplyInfo.java <==
package com.xdja.ra.bean;

/**
 * @author: ggp
 * @Date: 2019/10/22 20:12
 * @Description:
 */
public class IssueApplyInfo {
    /**
     *必须	申请原因
     */
    private String applyReason;
    /**
     *必须	申请状态 1:待审核 2:审核未通过 3:待签发 4:签发未通过 5:已签发 6:撤销失败 7:已撤销
     */
    private Integer applyStatus;
    /**
     *必须	申请证书DN
     */
    private String certDn;
    /**
     *必须	证书有效期
     */
    private Integer certValidity;
    /**
     *必须	申请创建时间
     */
    private String gmtCreate;
    /**
     *必须	密钥算法
     */
    private String keyAlg;
    /**
     *必须	用户证件编号
     */
    private String licenseNumber;
    /**
     *必须	不同类型用户相对应的用户身份类型 userType为1时 identType 1:身份证 2:军官证  3:护照 4:其它 userType为2时 identType 1:工商登记证 2:组织机构代码 3:税务登记证 4:其他 userType为3时 identType 1:服务器 2:手机 3:网站 4:其他
     */
    private Integer licenseType;
    /**
     *必须	密钥长度
     */
    private Integer privateKeyLength;
    /**
     *必须	证书签名算法
     */
    private String signAlg;
    /**
     *必须	模板名称
     */
    private String tempName;
    /**
     *必须	模板编号
     */
    private String tempNo;
    /**
     *必须	模板扩展参数
     */
    private String tempParas;
    /**
     *必须	申请用户的用户名
     */
    private String userName;
    /**
     *必须	申请用户的用户状态 0-正常 1-停用
     */
    private Integer userStatus;
    /**
     *必须	申请用户的用户类型 1-个人用户 2-机构用户 3-设备用户
     */
    private Integer userType;
    /**
     * 所属用户CA
     */
    private String userCA;

    public String getUserCA() {
        return userCA;
    }

    public void setUserCA(String userCA) {
        this.userCA = userCA;
    }

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public Integer getCertValidity() {
        return certValidity;
    }

    public void setCertValidity(Integer certValidity) {
        this.certValidity = certValidity;
    }

    public String getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(String gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getKeyAlg() {
        return keyAlg;
    }

    public void setKeyAlg(String keyAlg) {
        this.keyAlg = keyAlg;
    }

    public String getLicenseNumber() {
        return licenseNumber;
    }

    public void setLicenseNumber(String licenseNumber) {
        this.licenseNumber = licenseNumber;
    }

    public Integer getLicenseType() {
        return licenseType;
    }

    public void setLicenseType(Integer licenseType) {
        this.licenseType = licenseType;
    }

    public Integer getPrivateKeyLength() {
        return privateKeyLength;
    }

    public void setPrivateKeyLength(Integer privateKeyLength) {
        this.privateKeyLength = privateKeyLength;
    }

    public String getSignAlg() {
        return signAlg;
    }

    public void setSignAlg(String signAlg) {
        this.signAlg = signAlg;
    }

    public String getTempName() {
        return tempName;
    }

    public void setTempName(String tempName) {
        this.tempName = tempName;
    }

    public String getTempNo() {
        return tempNo;
    }

    public void setTempNo(String tempNo) {
        this.tempNo = tempNo;
    }

    public String getTempParas() {
        return tempParas;
    }

    public void setTempParas(String tempParas) {
        this.tempParas = tempParas;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public Integer getUserStatus() {
        return userStatus;
    }

    public void setUserStatus(Integer userStatus) {
        this.userStatus = userStatus;
    }

    public Integer getUserType() {
        return userType;
    }

    public void setUserType(Integer userType) {
        this.userType = userType;
    }

    @Override
    public String toString() {
        return "IssueApplyInfo{" +
                "applyReason='" + applyReason + '\'' +
                ", applyStatus=" + applyStatus +
                ", certDn='" + certDn + '\'' +
                ", certValidity=" + certValidity +
                ", gmtCreate='" + gmtCreate + '\'' +
                ", keyAlg='" + keyAlg + '\'' +
                ", licenseNumber='" + licenseNumber + '\'' +
                ", licenseType=" + licenseType +
                ", privateKeyLength=" + privateKeyLength +
                ", signAlg='" + signAlg + '\'' +
                ", tempName='" + tempName + '\'' +
                ", tempNo='" + tempNo + '\'' +
                ", tempParas='" + tempParas + '\'' +
                ", userName='" + userName + '\'' +
                ", userStatus=" + userStatus +
                ", userType=" + userType +
                ", userCA='" + userCA + '\'' +
                '}';
    }
}
